@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12806 2021-03-24 05:59:30Z Casey $
+# $Id: __init__.py 12853 2021-04-22 07:31:24Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $ (last)
-# $Date: 2021-03-24 13:59:30 +0800 (Wed, 24 Mar 2021) $
-# $Revision: 12806 $
+# $Author: Lavender $ (last)
+# $Date: 2021-04-22 15:31:24 +0800 (週四, 22 四月 2021) $
+# $Revision: 12853 $
 
 from __future__ import print_function
 
@@ -857,6 +857,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'IUNO_MEMBER_GMAIL_LOGIN_ENABLE': False,
             'IUNO_MEMBER_YAHOO_LOGIN_ENABLE': False,
             'IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE': False,
+            'IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE': False,
+            'IUNO_MEMBER_ACCOUNT_TIMEZONE_ENABLE': False,
         }
 
         update(settingsDict, iunoMemberDefaults)
@@ -870,7 +872,9 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                             settingsDict['IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
-                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
+                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE'],
+                            settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE'],
+                            settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE']
                         )
         else: # IUNO_MEMBER_ENABLE = False
             if warns:
@@ -1037,7 +1041,7 @@ def attachDebugURLs(settings, urlpatterns):
                 url(r'^__debug__/', include(debug_toolbar.urls)),
             )
 
-def attachURLs(settings, urlpatterns):
+def attachURLs(settings, urlpatterns, excludeApps=[]):
     """
     Attach patched (for example, debug and admin...etc.) urlpatterns.
     It must be called in urls.py by passing urlpatterns.
@@ -1053,6 +1057,20 @@ def attachURLs(settings, urlpatterns):
         url(r'^django-des/', include(des_urls)),
     )
 
+    #==========================================================================
+    # Iuno.member.
+    if not "Iuno.member" in excludeApps:
+        try:
+            module = checkImportPackageForAttachURLs('Iuno.member')
+        except ImportError:
+            pass
+        else:
+            if module:
+                import Iuno.member
+
+        if getattr(settings, 'IUNO_MEMBER_ENABLE', None) and module:
+            Iuno.member.attachURLs(settings, urlpatterns)
+
     #=========================================================================
     # Iuno.cloud.
     try:
@@ -1064,24 +1082,43 @@ def attachURLs(settings, urlpatterns):
             import Iuno.cloud
 
     if getattr(settings, 'IUNO_CLOUD_ENABLE', None) and module:
-        attachCloudKws = {}
+        attachCloudKws = {
+            'excludeApps': excludeApps,
+        }
         if hasattr(settings, 'IUNO_CLOUD_SERVICES'):
             attachCloudKws['services'] = settings.IUNO_CLOUD_SERVICES
 
         Iuno.cloud.attachURLs(settings, urlpatterns, **attachCloudKws)
 
+    #==========================================================================
+    # Iuno.shop.
+    if not "Iuno.shop" in excludeApps:
+        try:
+            module = checkImportPackageForAttachURLs('Iuno.shop')
+        except ImportError:
+            pass
+        else:
+            if module:
+                import Iuno.shop
+
+        if getattr(settings, 'IUNO_SHOP_ENABLE', None) and module:
+            Iuno.shop.attachURLs(settings, urlpatterns)
+        
     #==========================================================================
     # Iuno.test.
-    addTestUrl = False
-    if hasattr(settings ,'IUNO_TEST_ENABLE'):
-        addTestUrl = settings.IUNO_TEST_ENABLE
+    if not "Iuno.test" in excludeApps:
+        addTestUrl = False
+        if hasattr(settings ,'IUNO_TEST_ENABLE'):
+            addTestUrl = settings.IUNO_TEST_ENABLE
 
-    if addTestUrl:
-        from Iuno.test.views import test
-        urlpatterns += patterns('',
-            url(r"^remote/test/$", test, name="remoteTest"),
-        )
+        if addTestUrl:
+            from Iuno.test.views import test
+            urlpatterns += patterns('',
+                url(r"^remote/test/$", test, name="remoteTest"),
+            )
 
+    #==========================================================================
+    # DEBUG mode media
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
         if DJANGO_VERSION >= 11100: # django >= 1.11
             from django.views.static import serve
@@ -1097,27 +1134,4 @@ def attachURLs(settings, urlpatterns):
                 })
             )
 
-    #==========================================================================
-    # Iuno.shop.
-    try:
-        module = checkImportPackageForAttachURLs('Iuno.shop')
-    except ImportError:
-        pass
-    else:
-        if module:
-            import Iuno.shop
 
-    if getattr(settings, 'IUNO_SHOP_ENABLE', None) and module:
-        Iuno.shop.attachURLs(settings, urlpatterns)
-    #==========================================================================
-    # Iuno.member.
-    try:
-        module = checkImportPackageForAttachURLs('Iuno.member')
-    except ImportError:
-        pass
-    else:
-        if module:
-            import Iuno.member
-
-    if getattr(settings, 'IUNO_MEMBER_ENABLE', None) and module:
-        Iuno.member.attachURLs(settings, urlpatterns)
