@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12658 2020-12-25 01:35:21Z Lavender $
+# $Id: __init__.py 12844 2021-04-10 12:25:04Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-12-25 09:35:21 +0800 (週五, 25 十二月 2020) $
-# $Revision: 12658 $
+# $Author: Casey $ (last)
+# $Date: 2021-04-10 20:25:04 +0800 (週六, 10 四月 2021) $
+# $Revision: 12844 $
 
 import logging
 
@@ -82,8 +82,8 @@ def attachSettings(settingsLocals, backends, preferred, config):
         'RAVEN_CONFIG': {
             'dsn': hostInfo.info['SENTRY_DSN'],
         },
-        'MIDDLEWARE_CLASSES': \
-            list(settingsLocals.get('MIDDLEWARE_CLASSES', ())) + [
+        'MIDDLEWARE': \
+            list(settingsLocals.get('MIDDLEWARE', ())) + [
             ('raven.contrib.django.raven_compat.middleware.'
              'SentryResponseErrorIdMiddleware'),
         ],
