@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12555 2020-10-15 08:37:39Z Lavender $
+# $Id: models.py 12795 2021-03-10 17:23:54Z Lavender $
 #
 # Copyright (c) 2020 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-10-15 16:37:39 +0800 (週四, 15 十月 2020) $
-# $Revision: 12555 $
+# $Date: 2021-03-11 01:23:54 +0800 (週四, 11 三月 2021) $
+# $Revision: 12795 $
 
 import datetime
 
@@ -135,6 +135,14 @@ def ordererAddress2(self):
 
 Order.ordererAddress = ordererAddress2
 
+@property
+def useInvoice(self):
+    if hasattr(settings, "IUNO_SHOP_INVOICE_FROM"):
+        return settings.IUNO_SHOP_INVOICE_FROM
+    return False
+    
+Order.useInvoice = useInvoice
+
 # https://code.nuwainfo.com/trac/Mercurius/ticket/3296#ticket
 @property
 def useATM(self):
